==> mule-rogue-extension-4.6.25-20251204.223618-3-sources.jar: org/mule/test/rogue/extension/source/StopHangsSource.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.rogue.extension.source;

import static java.lang.Thread.currentThread;
import static java.lang.Thread.sleep;
import static java.util.concurrent.TimeUnit.SECONDS;

import org.mule.runtime.api.exception.MuleException;
import org.mule.runtime.api.scheduler.Scheduler;
import org.mule.runtime.api.scheduler.SchedulerService;
import org.mule.sdk.api.runtime.operation.Result;
import org.mule.sdk.api.runtime.source.Source;
import org.mule.sdk.api.runtime.source.SourceCallback;

import java.util.concurrent.ScheduledFuture;

import javax.inject.Inject;

/**
 * A source that never returns from its stop call
 */
public class StopHangsSource extends Source<String, Object> {

  @Inject
  private SchedulerService schedulerService;

  @Override
  public void onStart(SourceCallback<String, Object> sourceCallback) throws MuleException {
    Scheduler scheduler = schedulerService.cpuLightScheduler();
    ScheduledFuture<?> sourceDispatchHandle = scheduler.scheduleAtFixedRate(() -> {
      try {
        System.out.println("NeverStoppingSource dispatching...");
        sourceCallback.handle(Result.<String, Object>builder().output("hello!").build());
        System.out.println("NeverStoppingSource dispatched");
      } catch (Throwable t) {
        t.printStackTrace();
      }
    }, 0, 1, SECONDS);
  }

  @Override
  public void onStop() {
    try {
      sleep(5 * 60 * 1000);
    } catch (InterruptedException e) {
      currentThread().interrupt();
      return;
    }
  }

}

==> mule-rogue-extension-4.9.12-20251202.164803-1-sources.jar: org/mule/test/rogue/extension/source/StopHangsSource.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.test.rogue.extension.source;

import static java.lang.Thread.currentThread;
import static java.lang.Thread.sleep;
import static java.util.concurrent.TimeUnit.SECONDS;

import org.mule.runtime.api.exception.MuleException;
import org.mule.runtime.api.scheduler.SchedulerService;
import org.mule.sdk.api.runtime.operation.Result;
import org.mule.sdk.api.runtime.source.Source;
import org.mule.sdk.api.runtime.source.SourceCallback;

import javax.inject.Inject;

/**
 * A source that never returns from its stop call
 */
public class StopHangsSource extends Source<String, Object> {

  @Inject
  private SchedulerService schedulerService;

  @Override
  public void onStart(SourceCallback<String, Object> sourceCallback) throws MuleException {
    var scheduler = schedulerService.cpuLightScheduler();
    var sourceDispatchHandle = scheduler.scheduleAtFixedRate(() -> {
      try {
        System.out.println("NeverStoppingSource dispatching...");
        sourceCallback.handle(Result.<String, Object>builder().output("hello!").build());
        System.out.println("NeverStoppingSource dispatched");
      } catch (Throwable t) {
        t.printStackTrace();
      }
    }, 0, 1, SECONDS);
  }

  @Override
  public void onStop() {
    try {
      sleep(5 * 60 * 1000);
    } catch (InterruptedException e) {
      currentThread().interrupt();
      return;
    }
  }

}
